/* style */
import 'destyle.css'
import 'locomotive-scroll/dist/locomotive-scroll.css'
import '../scss/style.scss'

/* js */
import 'core-js/stable'
import './lib/_polyfill'
import LocomotiveScroll from 'locomotive-scroll'
import imagesLoaded from 'imagesloaded'
import { UAParser } from 'ua-parser-js'

import PixiView from './_pixi'
import MatterView from './_matter'
import MouseView from './_mouse-stalker'
import Progress from './_progress'

const debounce = (callback, duration) => {
  let timer;
  return (e) => {
    clearTimeout(timer);
    timer = setTimeout(() => callback(e), duration);
  }
}

const init = () => {
  const UA = new UAParser().getDevice();
  const hookEventForResize = UA.type !== undefined ? 'orientationchange' : 'resize';
  window.addEventListener(hookEventForResize, debounce(e => {
    window.location.reload();
  }, 600), false);

  const imageList = document.querySelectorAll('.js-image');
  const scroll = new LocomotiveScroll({
    el: document.querySelector('[data-scroll-container]'),
    smooth: true,
  });
  const pixiView = new PixiView('#l-canvas', imageList);
  const matterView = new MatterView('#l-matter', imageList, pixiView, UA.type !== undefined);

  Progress(
    document.querySelector('.js-progress'),
    document.querySelector('.js-progress__circle'),
    document.querySelector('.js-progress__number')
  );

  if(UA.type !== undefined) return;
  const mouseView = new MouseView(imageList);
}

window.addEventListener('DOMContentLoaded', () => {
  imagesLoaded('#l-wrapper', { background: true }, () => init());
});
